﻿using System;
using System.Linq;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Media;
using Abt.Controls.SciChart.Model.DataSeries;
using Abt.Controls.SciChart.Visuals.Annotations;
using Abt.Controls.SciChart.Visuals.RenderableSeries;

namespace Abt.Controls.SciChart.Wpf.TestSuite.TestCases.Histogram
{
    [TestCase("Histogram with Annotations")]
    public partial class HistogramExampleView : UserControl
    {
        public HistogramExampleView()
        {
            InitializeComponent();

            this.Loaded += new System.Windows.RoutedEventHandler(HistogramExampleView_Loaded);
        }

        private void HistogramExampleView_Loaded(object sender, System.Windows.RoutedEventArgs e)
        {            
            var series = new XyDataSeries<double, double>();
            series.SeriesName = "Histogram";

            var yValues = new double[] { 0.0, 0.1, 0.2, 0.4, 0.8, 1.1, 1.5, 2.4, 4.6, 8.1, 11.7, 14.4, 16.0, 13.7, 10.1, 6.4, 3.5, 2.5, 1.4, 0.4, 0.1, 0.0, 0.0 };

            for (int i = 0; i < yValues.Length; i++ )
            {
                // DataSeries for appending data
                series.Append(i, yValues[i]);   
 
                // Annotations for text labels
                var labelAnnotation = new TextAnnotation()
                                          {
                                              FontSize = 10,
                                              X1 = i,
                                              Y1 = yValues[i],
                                              Text = yValues[i].ToString(),
                                              Foreground = new SolidColorBrush(Color.FromArgb(0xFF,0x33,0x33,0x33)),
                                              FontWeight = FontWeights.Bold,
                                              VerticalAnchorPoint = VerticalAnchorPoint.Bottom,
                                              HorizontalAnchorPoint = HorizontalAnchorPoint.Center
                                          };

                this.sciChart.Annotations.Add(labelAnnotation);
            }

            columnSeries.DataSeries = series;
        }

        private void SliderValueChanged(object sender, RoutedPropertyChangedEventArgs<double> e)
        {
            if (this.sciChart != null)
            {
                var rSeries = (this.sciChart.RenderableSeries.FirstOrDefault() as FastColumnRenderableSeries);
                if (rSeries != null)
                {
                    rSeries.DataPointWidth = ((Slider) sender).Value;
                }
            }
        }
    }
}
